==> aws-java-sdk-inspector-1.10.77-sources.jar: com/amazonaws/services/inspector/model/transform/TimestampRangeJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.inspector.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.inspector.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * TimestampRangeMarshaller
 */
public class TimestampRangeJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(TimestampRange timestampRange,
            StructuredJsonGenerator jsonGenerator) {

        if (timestampRange == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (timestampRange.getBeginDate() != null) {
                jsonGenerator.writeFieldName("beginDate").writeValue(
                        timestampRange.getBeginDate());
            }
            if (timestampRange.getEndDate() != null) {
                jsonGenerator.writeFieldName("endDate").writeValue(
                        timestampRange.getEndDate());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static TimestampRangeJsonMarshaller instance;

    public static TimestampRangeJsonMarshaller getInstance() {
        if (instance == null)
            instance = new TimestampRangeJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-inspector-1.11.30-sources.jar: com/amazonaws/services/inspector/model/transform/TimestampRangeJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.inspector.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.inspector.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * TimestampRangeMarshaller
 */
public class TimestampRangeJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(TimestampRange timestampRange,
            StructuredJsonGenerator jsonGenerator) {

        if (timestampRange == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (timestampRange.getBeginDate() != null) {
                jsonGenerator.writeFieldName("beginDate").writeValue(
                        timestampRange.getBeginDate());
            }
            if (timestampRange.getEndDate() != null) {
                jsonGenerator.writeFieldName("endDate").writeValue(
                        timestampRange.getEndDate());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static TimestampRangeJsonMarshaller instance;

    public static TimestampRangeJsonMarshaller getInstance() {
        if (instance == null)
            instance = new TimestampRangeJsonMarshaller();
        return instance;
    }

}
